#!/bin/sh -e

case "$1" in
at4x0a)
	PLATFORM="at4x0a"
	CROSS_BUILD="i686-pc-linux-gnu"
	CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm926ej-s"
	;;
""|s3c24xx)
	PLATFORM="s3c24xx"
	CROSS_BUILD="i686-linux"
	CROSS_TARGET="arm-linux"
	CROSS_OPT="-O2"
	CROSS_CPU="arm920"
	;;
s3c64xx)
	PLATFORM="s3c64xx"
	CROSS_BUILD="i686-pc-linux-gnu"
	CROSS_TARGET="arm-none-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm1176jzf-s"
	;;
omap2)
	PLATFORM="omap2"
	CROSS_BUILD="i686-pc-linux-gnu"
	CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm1136jf-s"
	;;
titan2)
	PLATFORM="titan2"
	CROSS_BUILD="i686-pc-linux-gnu"
	#CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	# Temp, until TT toolchain is available.
	# Using CodeSourcery version now.
	CROSS_TARGET="arm-none-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm1136jf-s"
	;;
*)
	echo "$0: ERROR: Unknown platform \"$1\"."
	exit 1
	;;
esac

PROGNAME="freetype"
SRCDIR="${PWD}"

OBJDIR="${PWD}/obj-${PLATFORM}"
INSDIR="${PWD}/ins-${PLATFORM}"

export BUILD_CC="gcc"
export CC="${CROSS_TARGET}-gcc"
export CFLAGS="${CROSS_OPT} -mcpu=${CROSS_CPU} -ffunction-sections -fdata-sections"
export CXX="${CROSS_TARGET}-g++"
export CXXFLAGS="${CFLAGS}"
export F77="${CROSS_TARGET}-g77"
export AS="${CROSS_TARGET}-as"
export LD="${CROSS_TARGET}-ld"
export LDFLAGS="-Wl,--gc-sections"
export AR="${CROSS_TARGET}-ar"
export NM="${CROSS_TARGET}-nm"
export RANLIB="${CROSS_TARGET}-ranlib"
export STRIP="${CROSS_TARGET}-strip"

mkdir -p "${OBJDIR}"
cd "${OBJDIR}"

echo "**** Configuring ${PROGNAME} for ${PLATFORM}..."
"${SRCDIR}/configure"		\
  --build="${CROSS_BUILD}"	\
  --host="${CROSS_TARGET}"	\
  --target="${CROSS_TARGET}"	\
  --prefix=""

echo "**** Building ${PROGNAME} for ${PLATFORM}..."
make

echo "**** Installing ${PROGNAME} for ${PLATFORM}..."
make DESTDIR="${INSDIR}" install

echo "**** Successfully built & installed ${PROGNAME} for ${PLATFORM}:"
ls -l "${INSDIR}/lib"

# EOF
